"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateChangeHash = exports.assertStoreItems = void 0;
const botbuilder_stdlib_1 = require("botbuilder-stdlib");
const crypto_1 = require("crypto");
exports.assertStoreItems = (val, path) => {
    botbuilder_stdlib_1.assert.object(val, path);
};
/**
 * Utility function to calculate a change hash for a `StoreItem`.
 *
 * @remarks
 * This example calculates a change hash for an object that's been read in and then only writes it
 * back out if it's been modified:
 *
 * ```JavaScript
 * // Calculate state objects initial hash
 * const hash = calculateChangeHash(state);
 *
 * // Process the received activity
 * await processActivity(context, state);
 *
 * // Save state if changed
 * if (calculateChangeHash(state) !== hash) {
 *    await storage.write({ 'botState': state });
 * }
 * ```
 * @param item Item to calculate the change hash for.
 */
function calculateChangeHash(item) {
    // eslint-disable-next-line  @typescript-eslint/no-unused-vars
    const { eTag } = item, rest = __rest(item, ["eTag"]);
    const result = botbuilder_stdlib_1.stringify(rest);
    const hash = crypto_1.createHash('sha256', { encoding: 'utf-8' });
    const hashed = hash.update(result).digest('hex');
    return hashed;
}
exports.calculateChangeHash = calculateChangeHash;
//# sourceMappingURL=storage.js.map